<?php


namespace app\cbcrm\controller\crm\trade;


use app\cbcrm\controller\BaseUser;
use app\cbcrm\model\config\SettingModel;
use app\cbcrm\model\trade\TrademarkLocalModel;
use GuzzleHttp\Client;
use GuzzleHttp\Exception\GuzzleException;
use think\Exception;
use think\facade\Db;
use think\Request;

class Trademark extends BaseUser
{
    protected $apiUrl = 'http://haoip.tunke.cn/api';

    protected $api_key = '';
    protected $trade_money_ratio = '';

    public function __construct(Request $request)
    {
        parent::__construct($request);
        $this->api_key = (new SettingModel())->getConfigValue('trade', 'trade_key', $this->wid);
        $this->trade_money_ratio = (new SettingModel())->getConfigValue('trade', 'trade_money_ratio', $this->wid);
    }

    public function cloudList()
    {
        $page = \request()->get('page', 1, 'intval');
        $search_type = \request()->get('searchType');
        $search = \request()->get('search', '', 'strip_tags,trim,htmlspecialchars');
        $cls = \request()->get('cls',-1);
        $status = \request()->get('status', -1);
        $trade_status = \request()->get('trade_status', -1);
        $admin_status = \request()->get('admin_status', -1);
        $params = [
            'api_key' => $this->api_key,
            'page' => $page,
            'limit' => 15
        ];
        if ($search) {
            $params['search_type'] = $search_type;
            $params['search'] = $search;
        }
        if ($cls > -1) {
            $params['cls'] = $cls;
        }
        if ($status > -1) {
            $params['status'] = $status;
        }
        if ($trade_status > -1) {
            $params['trade_status'] = $trade_status;
        }
        if ($admin_status > -1) {
            $params['admin_status'] = $admin_status;
        }

        $client = new Client();
        try {
            $data = [
                'current_page' => 1,
                'data' => [],
                'last_page' => 1,
                'per_page' => 1,
                'total' => 0,
            ];
            $response = $client->request('GET', $this->apiUrl . '/trade/trademark/getCloudList', [
                'query' => $params
            ]);
            $result = json_decode($response->getBody(), true);
            if ($result['code'] != 1) {
                throw new Exception($result['msg']);
            }
            $list = $result['data']['list'];
            $model = app()->make(TrademarkLocalModel::class);
            foreach ($list as &$item) {
                $item['range'] = subtext($item['range'], 30);
                if ($item['key'] && $item['key'] == $this->api_key) {
                   $localRow = $model->where('unique_id',$item['unique_id'])->where('wid',$this->wid)->find();
                    if ($localRow) {
                        $item['price'] = number_format($localRow['price']);
                        $item['sale_price'] = number_format($localRow['sale_price']);
                    }
                }else{
                    $item['price'] = $item['price']/100;
                    if ($this->trade_money_ratio) {
                        $item['sale_price'] = number_format($item['price'] + round($item['price'] * ($this->trade_money_ratio / 100)));
                    } else {
                        $item['sale_price'] = number_format($item['price']);
                    }
                    $item['price'] = number_format($item['price']);
                }
            }
            $data = [
                'current_page' => $page,
                'data' => $list,
                'last_page' => ceil($result['data']['total'] / 15),
                'per_page' => 15,
                'total' => $result['data']['total'],
            ];
            return success('返回成功', $data);
        } catch (GuzzleException $e) {
            return error($e->getMessage(), $data);
        } catch (Exception $e) {
            return error($e->getMessage(), $data);
        }
    }

    public function localList()
    {
        $params = [
            'wid'=>$this->wid
        ];
        $model = app()->make(TrademarkLocalModel::class);
        $list = $model->where($params)->order('sort_id desc,create_time desc')->paginate(15);

        foreach ($list as &$item) {
            $item->tm_trade_image = cdnurl($item->tm_trade_image);
        }

        return success('返回成功',$list);
    }

    public function getLoaclDetail()
    {
        $id = $this->request->get('id',0,'intval');
        $model = app()->make(TrademarkLocalModel::class);
        $row = $model->where('wid',$this->wid)->where('id',$id)->find();
        if (!$row) {
            return error('数据不存在');
        }
        $row['tm_trade_image_preview'] = $row->tm_trade_image_preview;
        $row['tm_trade_custom_image_preview'] = $row->tm_trade_custom_image_preview;
        $row['regist_issue_img_preview'] = $row->regist_issue_img_preview;
        $row['preliminary_issue_img_preview'] = $row->preliminary_issue_img_preview;
        return success('返回成功',$row);
    }

    public function local_add()
    {
        $params = \request()->post('form');
        $params['wid'] = $this->wid;
        if (!isset($params['sale_price']) || !$params['sale_price']) {
            $params['sale_price'] = $params['price'] + round($params['price'] * ($this->trade_money_ratio / 100));
        }
        $model = app()->make(TrademarkLocalModel::class);
        $result = $model->save($params);
        return success('添加成功');
    }

    public function local_edit()
    {
        $id = \request()->post('id',0,'intval');
        $model = app()->make(TrademarkLocalModel::class);
        $params = \request()->post('form');
        if (!isset($params['sale_price']) || !$params['sale_price']) {
            $params['sale_price'] = $params['price'] + round($params['price'] * ($this->trade_money_ratio / 100));
        }
        $row = $model->where('id',$id)->where('wid',$this->wid)->find();
        if (!$row) {
            return error('数据不存在');
        }
        $row->save($params);

        $model->sync_cloud($row,$this->apiUrl,$this->api_key);

        return success('编辑成功');
    }

    public function local_del()
    {
        $id = \request()->delete('id',0,'intval');
        $model = app()->make(TrademarkLocalModel::class);
        $row = $model->where('id',$id)->where('wid',$this->wid)->find();
        if (!$row) {
            return error('数据不存在');
        }
        Db::startTrans();
        try {
            // 同步删除云库
            if ($row->unique_id) {
                $client = new Client();
                $response = $client->request('POST', $this->apiUrl . '/trade/trademark_local/sync_del', [
                    'query' => ['api_key' => $this->api_key],
                    'json'=>[
                        'domain'=>\request()->domain(),
                        'unique_id'=>$row->unique_id
                    ]
                ]);
                $result = json_decode($response->getBody(), true);
                if ($result['code'] != 1) {
                    throw new Exception($result['msg']);
                }
            }
            $row->delete();
            Db::commit();
        } catch (Exception|GuzzleException $e) {
            Db::rollback();
            return error($e->getMessage());
        }
        return success('删除成功');
    }

    /*
     * 本地库同步至商标云库平台
     * */
    public function local_sync()
    {
        $ids = \request()->post('ids');

        $model = app()->make(TrademarkLocalModel::class);

        $list = $model->where('id','IN',$ids)->where('wid',$this->wid)->select();
        foreach ($list as $row) {
           $result = $model->sync_cloud($row,$this->apiUrl,$this->api_key);
            if ($result !==true) {
                return error($result);
            }
        }
        return success('同步成功');

    }
}
