<?php


namespace app\cbcrm\model\customer;


use think\Exception;
use think\facade\Db;
use think\Model;
use think\model\concern\SoftDelete;

class AttachmentModel extends Model
{
    use SoftDelete;

    protected $table = 'cb_crm_customer_attachment';

    public function getList($where,$wid)
    {
        $list = $this->withJoin(['customer'],'LEFT')
            ->where($where)
            ->order('create_time','desc')
            ->paginate(10);
        foreach ($list as $row) {
            if (!$row['is_super']) {
                $row['staff'] = Db::table('cb_crm_staff')->where('wid',$wid)->where('id',$row['staff_id'])->field('id,nickname')->find();
            }else{
                $row['staff'] = null;
            }
            $filesArr = [];
            if ($row->files) {
                $files = explode(',',$row->files);
                foreach ($files as $file) {
                    array_push($filesArr,[
                        'url'=>$file,
                        'preview_url'=>cdnurl($file)
                    ]);
                }
            }
            $row->filesArr = $filesArr;
        }

        return $list;
    }

    /*
     * 添加材料
     * */
    public function addAttach($params,$wid)
    {
        $result = false;
        Db::startTrans();
        try {
            $params['wid'] = $wid;
            if ($params['files']) {
                $params['files'] = implode(',',$params['files']);
            }
            if (isset($params['range_date']) && $params['range_date']) {
                $params['starttime'] = $params['range_date'][0];
                $params['endtime'] = $params['range_date'][1];
            }
            $result = $this->save($params);
            (new OperateModel())->addLog("添加客户材料[{$params['name']}]",$params['customer_id'],$wid,$params);
            Db::commit();
        } catch (Exception $e) {
            Db::rollback();
            return $e->getMessage();
        }
        if ($result) {
            return true;
        }
    }

    /*
     * 编辑材料
     * */
    public function editAttach($id,$params,$wid)
    {
        $row = $this->where('id',$id)->where('wid',$wid)->find();
        if (!$row) {
            abort(404,'记录不存在');
        }
        $result = false;
        Db::startTrans();
        try {
            if ($params['files']) {
                $params['files'] = implode(',',$params['files']);
            }
            if (isset($params['range_date']) && $params['range_date']) {
                $params['starttime'] = $params['range_date'][0];
                $params['endtime'] = $params['range_date'][1];
            }
            $result = $row->save($params);
            (new OperateModel())->addLog("编辑客户材料[{$params['name']}]",$params['customer_id'],$wid,$params);

            Db::commit();
        } catch (Exception $e) {
            Db::rollback();
            return $e->getMessage();
        }
        if ($result) {
            return true;
        }
    }

    /*
     * 删除材料
     * */
    public function delAttach($id,$wid)
    {
        $row = $this->where('id',$id)->where('wid',$wid)->find();
        if (!$row) {
            abort(404,'记录不存在');
        }
        $result = false;
        Db::startTrans();
        try {
            $result = $row->delete();
            (new OperateModel())->addLog("删除客户材料[{$row['name']}]",$row['customer_id'],$wid,$row);
            Db::commit();
        } catch (Exception $e) {
            Db::rollback();
            return $e->getMessage();
        }
        if ($result) {
            return true;
        }
    }

    public function customer()
    {
        return $this->belongsTo(CustomerModel::class,'customer_id','id')->field('id,name');
    }
}
